Skip to main contentModule instruction
Source - Instruction
- A decoded Lua 5.1 instruction.
- InstructionFields
- The variable part of a decoded instruction, depending on the opcode format.
- BITRK
- Bit 8 of a B/C field indicates a constant index rather than a register.
- LFIELDS_PER_FLUSH
- Number of list items to accumulate before a SETLIST instruction.
- encode_abc
- Encode helpers (useful for testing)
- encode_abx
- encode_asbx
- index_k
- Extract the constant index from an RK value.
- is_k
- Check whether a B/C value refers to a constant (vs register).