Module liveness

Module liveness 

Structs

LivenessInfo
Liveness information for a CFG.
RegUsage
Per-instruction register usage info.

Functions

compute_liveness
Compute liveness analysis for the given CFG. Returns per-block live-in and live-out sets.
instruction_reg_usage
Compute register defs/uses for a single instruction.
is_reg_live_after
Check if a register is live at a given pc within a block. This does a local scan from end of block backwards.